@@ -27,22 +27,7 @@ class FileWidget(TextInput):
         super(FileWidget, self).__init__(default_attrs)
 
     def render(self, name, value, attrs):
-        html = super(FileWidget, self).render(name, value, attrs)
-
-        if value:
-            if isinstance(value, basestring):
-                value = UploadCare().file(value)
-
-            if value.url:
-                fname = '<a href="{0}">{1}</a>'.format(value.url, value.filename)
-            else:
-                fname = '{0} ({1})'.format(value.filename, _('unavail.'))
-
-            description = '<p>{0}: {1}</p>'.format(_('File'), fname)
-
-            html = mark_safe(html + description)
-
-        return html
+        return super(FileWidget, self).render(name, value, attrs)
 
 
 class FileField(Field):
